==> fillets-ng-data_0.7.1.orig.tar.gz: fillets-ng-data-0.7.1/script/viking1/dialogs_de.lua <==

dialogId("dr-m-tojesnad", "font_small", "This must be a Viking ship!")
dialogStr("Das muss ein Wikingerschiff sein!")


dialogId("dr-v-jiste", "font_big", "Sure, it`s a drakkar.")
dialogStr("Sicher, es ist eine Drakkar.")


dialogId("dr-m-musela", "font_small", "She must have sunk fast. The oarsmen are still in their places.")
dialogStr("Sie muss schnell gesunken sein. Die Ruderer sind noch auf ihren Plätzen.")


dialogId("dr-v-mozna", "font_big", "Maybe they sank her on purpose. Warriors would always accompany their leader on his way to Valhalla.")
dialogStr("Vielleicht wurde sie auch mit Absicht versenkt. Kämpfer würden ihrem Führer immer auf dem Weg nach Walhalla folgen.")


dialogId("dr-m-hruza", "font_small", "That's awful. They look like they're still alive.")
dialogStr("Das ist schrecklich. Die sehen aus, als wären sie immer noch lebendig.")


dialogId("d1-1-hudba0", "font_viking1", "The music is gone!")
dialogStr("Die Musik ist aus!")


dialogId("d1-1-hudba1", "font_viking1", "They stopped playing!")
dialogStr("Die haben aufgehört zu spielen!")


dialogId("d1-1-hudba2", "font_viking1", "The music stopped again!")
dialogStr("Die Musik hat wieder aufgehört!")


dialogId("d1-2-brb0", "font_viking2", "Oh, no!")
dialogStr("Oh, nein!")


dialogId("d1-2-brb1", "font_viking2", "Again?")
dialogStr("Schon wieder?")


dialogId("d1-2-brb2", "font_viking2", "Oh, not again!")
dialogStr("Oh, nicht schon wieder!")


dialogId("d1-3-brb0", "font_viking3", "What happened?")
dialogStr("Was ist passiert?")


dialogId("d1-3-brb1", "font_viking3", "Again?")
dialogStr("Schon wieder?")


dialogId("d1-3-brb2", "font_viking3", "Oh, no!")
dialogStr("Oh, nein!")


dialogId("d1-4-brb0", "font_viking4", "The bloody music stopped!")
dialogStr("Die verdammte Musik hat wieder aufgehört!")


dialogId("d1-4-brb1", "font_viking4", "What are they doing up there?")
dialogStr("Was machen die da oben?")


dialogId("d1-4-brb2", "font_viking4", "How could it be?")
dialogStr("Wie kann das sein?")


dialogId("d1-5-nevadi0", "font_viking5", "Take it easy, boys. Solo for Olaf!")
dialogStr("Immer mit der Ruhe, Jungs. Ein Solo für Olaf!")


dialogId("d1-5-nevadi1", "font_viking5", "Never mind that, boys. We can sing ourself!")
dialogStr("Das macht doch nichts, Jungs. Wir können selbst singen!")


dialogId("d1-5-nevadi2", "font_viking5", "Never mind, boys. We can sing ourself, like in the old times!")
dialogStr("Macht nichts, Jungs. Wir können selbst singen, wie in alten Zeiten!")

==> fillets-ng-data_0.8.0.orig.tar.gz: fillets-ng-data-0.8.0/script/viking1/dialogs_de.lua <==

dialogId("dr-m-tojesnad", "font_small", "This must be a Viking ship!")
dialogStr("Das muss ein Wikingerschiff sein!")


dialogId("dr-v-jiste", "font_big", "Sure, it’s a drakkar.")
dialogStr("Sicher, es ist eine Drakkar.")


dialogId("dr-m-musela", "font_small", "She must have sunk fast. The oarsmen are still in their places.")
dialogStr("Sie muss schnell gesunken sein. Die Ruderer sind noch auf ihren Plätzen.")


dialogId("dr-v-mozna", "font_big", "Maybe they sank her on purpose. Warriors would always accompany their leader on his way to Valhalla.")
dialogStr("Vielleicht wurde sie auch mit Absicht versenkt. Kämpfer würden ihrem Führer immer auf dem Weg nach Walhalla folgen.")


dialogId("dr-m-hruza", "font_small", "That's awful. They look like they're still alive.")
dialogStr("Das ist schrecklich. Die sehen aus, als wären sie immer noch lebendig.")


dialogId("d1-1-hudba0", "font_viking1", "The music is gone!")
dialogStr("Die Musik ist aus!")


dialogId("d1-1-hudba1", "font_viking1", "They stopped playing!")
dialogStr("Die haben aufgehört zu spielen!")


dialogId("d1-1-hudba2", "font_viking1", "The music stopped again!")
dialogStr("Die Musik hat wieder aufgehört!")


dialogId("d1-2-brb0", "font_viking2", "Oh, no!")
dialogStr("Oh, nein!")


dialogId("d1-2-brb1", "font_viking2", "Again?")
dialogStr("Schon wieder?")


dialogId("d1-2-brb2", "font_viking2", "Oh, not again!")
dialogStr("Oh, nicht schon wieder!")


dialogId("d1-3-brb0", "font_viking3", "What happened?")
dialogStr("Was ist passiert?")


dialogId("d1-3-brb1", "font_viking3", "Again?")
dialogStr("Schon wieder?")


dialogId("d1-3-brb2", "font_viking3", "Oh, no!")
dialogStr("Oh, nein!")


dialogId("d1-4-brb0", "font_viking4", "The bloody music stopped!")
dialogStr("Die verdammte Musik hat wieder aufgehört!")


dialogId("d1-4-brb1", "font_viking4", "What are they doing up there?")
dialogStr("Was machen die da oben?")


dialogId("d1-4-brb2", "font_viking4", "How could it be?")
dialogStr("Wie kann das sein?")


dialogId("d1-5-nevadi0", "font_viking5", "Take it easy, boys. Solo for Olaf!")
dialogStr("Immer mit der Ruhe, Jungs. Ein Solo für Olaf!")


dialogId("d1-5-nevadi1", "font_viking5", "Never mind that, boys. We can sing ourself!")
dialogStr("Das macht doch nichts, Jungs. Wir können selbst singen!")


dialogId("d1-5-nevadi2", "font_viking5", "Never mind, boys. We can sing ourself, like in the old times!")
dialogStr("Macht nichts, Jungs. Wir können selbst singen, wie in alten Zeiten!")
